library ldy_radio_group;

import 'package:flutter/material.dart';
import 'package:radio_group/custom-colors.dart';

typedef void OnChangeHandler(Map<String, dynamic> e);

class RadioGroupState extends State<RadioGroup> {
  List<Widget> createBody() {
    final widgets = <Widget>[
      Wrap(
        children: widget.data.map((item) {
          final bool selected = item['value'] == widget.value;
          return Container(
            width: 80.0,
            height: 30.0,
            margin: EdgeInsets.all(10.0),
            child: FlatButton(
              shape: StadiumBorder(
                side: BorderSide(
                  color: selected ? CustomColors.STANDARD_BLUE : CustomColors
                    .BORDER_GREY
                )
              ),
              padding: EdgeInsets.all(0.0),
              color: selected ? CustomColors.STANDARD_BLUE : Colors.white,
              highlightColor: selected ? Colors.white10 : Color(0x05FFFFFF),
              splashColor: selected ? Colors.white30 : CustomColors.SPLASH_BLUE,
              textColor: selected ? Colors.white : CustomColors.TEXT_GREY,
              child: Directionality(
                textDirection: TextDirection.ltr,
                child: Text(
                  item['name'],
                ),
              ),
              onPressed: () {
                widget.onChange(item);
              }
            )
          );
        }).toList()
      )
    ];
    if (widget.title != null && widget.title != '') {
      widgets.insert(0, Container(
        margin: EdgeInsets.fromLTRB(16, 12, 16, 12),
        child: Directionality(
          child: Text(
            widget.title,
            style: TextStyle(
              color: CustomColors.TEXT_GREY,
            )
          ),
          textDirection: TextDirection.ltr,
        ),
      ));
    }
    return widgets;
  }

  @override
  Widget build(BuildContext ctx) {
    return Container(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          mainAxisSize: MainAxisSize.min,
          children: createBody()
        )
      );
  }
}

class RadioGroup extends StatefulWidget {
  final List<Map<String, dynamic>> data;
  final OnChangeHandler onChange;
  final num value;
  final String title;

  RadioGroup({
    this.data,
    this.onChange,
    this.title,
    this.value
  });

  @override
  State<RadioGroup> createState() => RadioGroupState();
}
